@@ -12,6 +12,7 @@ from sqlalchemy.orm import Session
 
 from nowcasting_forecast import N_GSP, __version__
 from nowcasting_forecast.batch import make_batches
+from nowcasting_forecast.models.nwp_simple_trained.model import Model
 from nowcasting_forecast.models.nwp_simple_trained.nwp_simple_trained import (
     nwp_irradiance_simple_trained_run_one_batch,
 )
@@ -88,6 +89,7 @@ def run(db_url: str, fake: bool = False, model_name: str = "nwp_simple"):
                         batches_dir=temporary_dir,
                         callable_function_for_on_batch=nwp_irradiance_simple_trained_run_one_batch,
                         model_name="nwp_simple_trained",
+                        ml_model=Model,
                     )
                 else:
                     raise NotImplementedError(f"model name {model_name} has not be implemented. ")
