@@ -208,6 +208,8 @@ def general_forecast_run_all_batches(
     add_national_forecast: bool = True,
     n_gsps: int = N_GSP,
     batches_dir: Optional[str] = None,
+    ml_model: Optional = None,
+    weights_file: Optional[str] = None,
 ) -> List[ForecastSQL]:
     """Run model for all batches"""
 
@@ -232,6 +234,13 @@ def general_forecast_run_all_batches(
     # make dataloader
     dataloader = iter(BatchDataLoader(n_batches=n_batches, configuration=configuration))
 
+    # make pytorch model
+    if ml_model is not None:
+        model = ml_model()
+        model = model.load_model(remote_filename=weights_file)
+    else:
+        model = None
+
     # loop over batch
     forecasts = []
     for i in range(n_batches):
@@ -239,14 +248,14 @@ def general_forecast_run_all_batches(
 
         # calculate how many examples are needed
         n_examples = np.min([N_GSP - i * batch_size, batch_size])
-
         batch = next(dataloader)
-        forecasts.append(
-            callable_function_for_on_batch(
-                batch=batch,
-                n_examples=n_examples,
-            )
-        )
+
+        callbacks_args = dict(batch=batch, n_examples=n_examples)
+
+        if ml_model is not None:
+            callbacks_args["pytorch_model"] = model
+
+        forecasts.append(callable_function_for_on_batch(**callbacks_args))
 
     # make into one big dataframe
     forecasts = pd.concat(forecasts)
